@@ -42,6 +42,7 @@ class FileList:
         self.orientations = [0] * self.numfiles
         self.images = ["PENDING"] * self.numfiles  # PENDING | RELEASED | INVALID
         self.textures = [None] * self.numfiles     # None | <Texture>
+        self.metadata = [None] * self.numfiles
         self.is_url = [None] * self.numfiles
         self._update()
 
@@ -52,6 +53,7 @@ class FileList:
                 self.filespecs.pop(idx)
                 self.orientations.pop(idx)
                 self.textures.pop(idx)
+                self.metadata.pop(idx)
                 self.images.pop(idx)
                 self._update()
             except IndexError:
@@ -64,6 +66,7 @@ class FileList:
                 filespec = self.filespecs.pop(idx)
                 self.orientations.pop(idx)
                 self.textures.pop(idx)
+                self.metadata.pop(idx)
                 self.images.pop(idx)
                 self._update()
                 print(f"[{threading.current_thread().name}] Deleting {filespec}...")
@@ -83,6 +86,7 @@ def main():
     url = argv.stringval("--url", default=None)
     smooth = argv.exists("--filter")
     verbose = argv.exists("--verbose")
+    verbose += argv.exists("--verbose")
     show_help = argv.exists("--help")
     argv.exitIfAnyUnparsedOptions()
     if show_help:
@@ -94,6 +98,7 @@ def main():
         print("    --url <address>         load image from the given web address")
         print("    --filter                use linear filtering; default = nearest")
         print("    --verbose               print extra traces to the console")
+        print("    --verbose               print even more traces to the console")
         print("    --help                  show this help message")
         print()
         print("  runtime:")
@@ -107,11 +112,13 @@ def main():
         print("    s                       split window into 1/2/3/4 tiles")
         print("    1 / 2 / 3 / 4           select active tile for PageUp/PageDown/r")
         print("    w                       write current tile(s) to a PNG")
-        print("    h                       reset zoom & pan to initial state")
+        print("    h                       reset zoom/pan/exposure to initial state")
         print("    f                       toggle fullscreen <-> windowed")
         print("    t                       toggle nearest <-> linear filtering")
         print("    g                       toggle sRGB gamma correction on/off")
-        print("    b                       increase brightness in 0.5 EV steps")
+        print("    e                       slide exposure from -2EV to +2EV & back")
+        print("    b                       toggle between HDR/LDR exposure control")
+        print("    c                       toggle gamut compression on/off")
         print("    i                       print image information (EXIF)")
         print("    d                       drop the currently shown image")
         print("    del                     delete the currently shown image")
@@ -132,8 +139,8 @@ def main():
     enforce(numfiles > 0, "No valid images to show. Terminating.")
 
     files = FileList(filenames)
-    ui = pygletui.PygletUI(files, verbose)
-    loader = imageprovider.ImageProvider(files, verbose)
+    ui = pygletui.PygletUI(files, bool(verbose))
+    loader = imageprovider.ImageProvider(files, bool(verbose))
     renderer = glrenderer.GLRenderer(ui, files, loader, verbose)
     ui.texture_filter = "LINEAR" if smooth else "NEAREST"
     ui.fullscreen = fullscreen
@@ -149,7 +156,7 @@ def main_loop(modules):
     """ Keep the application running until exit request or out of memory. """
     try:
         ram_minimum = 512  # exit if available RAM drops below 512 MB
-        while all([m.running for m in modules]):
+        while all(m.running for m in modules):
             ram_available = psutil.virtual_memory().available / 1024**2
             if ram_available < ram_minimum:
                 print(f"ERROR: Only {ram_available:.0f} MB of RAM remaining. Terminating.")
